DeeplinkInfo class abstract

Data class for DeeplinkInfo

Annotations
  • @freezed

Constructors

DeeplinkInfo({required String qr, required String url, SourceInfo? sourceInfo})
Creates a instance of DeeplinkInfo
factory
DeeplinkInfo.fromJson(Map<String, dynamic> json)
Creates a instance of DeeplinkInfo from json map
factory

Properties

copyWith → $DeeplinkInfoCopyWith<DeeplinkInfo>
Create a copy of DeeplinkInfo with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
qr String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceInfo SourceInfo?
no setterinherited
url String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this DeeplinkInfo to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited