IndividualInfo class abstract

Data class for IndividualInfo

Annotations
  • @freezed

Constructors

IndividualInfo({required String bakongAccountId, String? accountInformation, String? acquiringBank, @Default.new(KhqrCurrency.khr) KhqrCurrency currency, @Default.new(0) double amount, required String merchantName, @Default.new('Phnom Penh') String merchantCity, String? billNumber, String? mobileNumber, String? storeLabel, String? terminalLabel, String? purposeOfTransaction, String? upiAccountInformation, String? merchantAlternateLanguagePreference, String? merchantNameAlternateLanguage, String? merchantCityAlternateLanguage, int? expirationTimestamp})
Creates a new instance of IndividualInfo
factory
IndividualInfo.fromJson(Map<String, dynamic> json)
Creates a new instance of IndividualInfo from a JSON map
factory

Properties

accountInformation String?
no setterinherited
acquiringBank String?
no setterinherited
amount double
no setterinherited
bakongAccountId String
no setterinherited
billNumber String?
no setterinherited
copyWith → $IndividualInfoCopyWith<IndividualInfo>
Create a copy of IndividualInfo with the given fields replaced by the non-null parameter values.
no setterinherited
currency KhqrCurrency
no setterinherited
expirationTimestamp int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
merchantAlternateLanguagePreference String?
no setterinherited
merchantCity String
no setterinherited
merchantCityAlternateLanguage String?
no setterinherited
merchantName String
no setterinherited
merchantNameAlternateLanguage String?
no setterinherited
mobileNumber String?
no setterinherited
purposeOfTransaction String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeLabel String?
no setterinherited
terminalLabel String?
no setterinherited
upiAccountInformation String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this IndividualInfo to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited