KhqrData class abstract

Data class for KhqrData

Annotations
  • @freezed

Constructors

KhqrData({required String qr, required String md5})
Creates a new instance of KhqrData
factory
KhqrData.fromJson(Map<String, dynamic> json)
Creates a instance of KhqrData from a JSON map
factory

Properties

copyWith → $KhqrDataCopyWith<KhqrData>
Create a copy of KhqrData with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
md5 String
no setterinherited
qr String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this KhqrData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited