DeeplinkData class abstract
Data class for DeeplinkData
- Annotations
-
- @freezed
Constructors
- DeeplinkData({required String shortLink})
-
Creates a new instance of DeeplinkData
factory
-
DeeplinkData.fromJson(Map<
String, dynamic> json) -
Creates a new instance of DeeplinkData from a JSON map
factory
Properties
-
copyWith
→ $DeeplinkDataCopyWith<
DeeplinkData> -
Create a copy of DeeplinkData
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortLink → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this DeeplinkData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited