KhqrCardWidget class
KhqrCardWidget is a widget that displays a KHQR card
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- KhqrCardWidget
Constructors
- KhqrCardWidget({Key? key, double width = 300, EdgeInsets? padding, required String receiverName, double amount = 0.0, required KhqrCurrency currency, required String qr, bool keepIntegerDecimal = false, Duration? duration, bool showEmptyAmount = true, bool showCurrencySymbol = true, bool? isDark, bool showShadow = true, Widget? expiredWidget, dynamic onRetry()?})
-
Creates a KhqrCardWidget
const
Properties
- amount → double
-
The amount of the transaction
final
- currency → KhqrCurrency
-
The currency of the transaction
final
- duration → Duration?
-
The duration of qr code expiration
final
- expiredWidget → Widget?
-
The widget to show when qr code is expired
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDark → bool?
-
Whether to use dark mode
final
- keepIntegerDecimal → bool
-
Whether to keep the integer decimal of the amount
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onRetry → dynamic Function()?
-
The callback when retry
final
- padding → EdgeInsets?
-
The padding of the QR code
final
- qr → String
-
The KHQR code
final
- receiverName → String
-
The name of the receiver
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCurrencySymbol → bool
-
Whether to show currency symbol
final
- showEmptyAmount → bool
-
Whether to show the empty amount
final
- showShadow → bool
-
Whether to show shadow
final
- width → double
-
The width of the card
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< KhqrCardWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited