KhqrDecodedData class abstract
Data class for KhqrDecodedData
- Annotations
-
- @freezed
Constructors
- KhqrDecodedData({String? payloadFormatIndicator, String? pointOfInitiationMethod, String? bakongAccountId, String? merchantId, String? accountInformation, String? acquiringBank, String? merchantType, String? transactionCurrency, String? merchantName, String? transactionAmount, String? merchantCategoryCode, String? countryCode, String? merchantCity, String? billNumber, String? storeLabel, String? terminalLabel, String? mobileNumber, String? crc, String? upiAccountInformation, String? purposeOfTransaction, String? merchantAlternateLanguagePreference, String? merchantNameAlternateLanguage, String? merchantCityAlternateLanguage, String? creationTimestamp, String? expirationTimestamp})
-
Creates new instance of KhqrDecodedData
factory
-
KhqrDecodedData.fromJson(Map<
String, dynamic> json) -
Creates new instance of KhqrDecodedData from JSON map
factory
Properties
- accountInformation → String?
-
no setterinherited
- acquiringBank → String?
-
no setterinherited
- bakongAccountId → String?
-
no setterinherited
- billNumber → String?
-
no setterinherited
-
copyWith
→ $KhqrDecodedDataCopyWith<
KhqrDecodedData> -
Create a copy of KhqrDecodedData
with the given fields replaced by the non-null parameter values.
no setterinherited
- countryCode → String?
-
no setterinherited
- crc → String?
-
no setterinherited
- creationTimestamp → String?
-
no setterinherited
- expirationTimestamp → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantAlternateLanguagePreference → String?
-
no setterinherited
- merchantCategoryCode → String?
-
no setterinherited
- merchantCity → String?
-
no setterinherited
- merchantCityAlternateLanguage → String?
-
no setterinherited
- merchantId → String?
-
no setterinherited
- merchantName → String?
-
no setterinherited
- merchantNameAlternateLanguage → String?
-
no setterinherited
- merchantType → String?
-
no setterinherited
- mobileNumber → String?
-
no setterinherited
- payloadFormatIndicator → String?
-
no setterinherited
- pointOfInitiationMethod → String?
-
no setterinherited
- purposeOfTransaction → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeLabel → String?
-
no setterinherited
- terminalLabel → String?
-
no setterinherited
- transactionAmount → String?
-
no setterinherited
- transactionCurrency → String?
-
no setterinherited
- upiAccountInformation → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this KhqrDecodedData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited