KhqrSdk class
KHQR SDK class to generate, verify and decode QR codes
Constructors
- KhqrSdk()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String qrCode) → Future< KhqrDecodedData?> - Decode a KHQR code.
-
decodeNonKhqr(
String qrCode) → Future< Map< String, dynamic> ?> - Decode a Non KHQR code.
-
generateDeepLink(
DeeplinkInfo info) → Future< DeeplinkData?> - Generate a KHQR deeplink.
-
generateIndividual(
IndividualInfo info) → Future< KhqrData?> - Generate a KHQR for an individual
-
generateMerchant(
MerchantInfo info) → Future< KhqrData?> - Generate a KHQR for a merchant
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
String qrCode) → Future< bool> - Verify a KHQR code.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited