SourceInfo class abstract
Data class for SourceInfo
- Annotations
-
- @freezed
Constructors
- SourceInfo({required String appIconUrl, required String appName, required String appDeepLinkCallBack})
-
Creates a new instance of SourceInfo
factory
-
SourceInfo.fromJson(Map<
String, dynamic> json) -
Creates a new instance of SourceInfo from a JSON map
factory
Properties
- appDeepLinkCallBack → String
-
no setterinherited
- appIconUrl → String
-
no setterinherited
- appName → String
-
no setterinherited
-
copyWith
→ $SourceInfoCopyWith<
SourceInfo> -
Create a copy of SourceInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this SourceInfo to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited